@@ -33,7 +33,7 @@ use strict;
 ##==============================================================================
 ## Globals & Constants
 
-our $VERSION = "0.07.004";
+our $VERSION = "0.07.010";
 our @ISA = qw(DiaColloDB::Client);
 
 ## $PGOOD_DEFAULT
@@ -73,8 +73,8 @@ our $XECLASS = 'DiaColloDB::EnumFile::FixedLen::MMap';
 
 ## $MMCLASS
 ##  + multimap class
-#our $MMCLASS = 'DiaColloDB::MultiMapFile';
-our $MMCLASS = 'DiaColloDB::MultiMapFile::MMap';
+our $MMCLASS = 'DiaColloDB::MultiMapFile';
+#our $MMCLASS = 'DiaColloDB::MultiMapFile::MMap'; ##-- TODO
 
 ##==============================================================================
 ## Constructors etc.
@@ -1078,7 +1078,8 @@ sub dbinfo {
 	       } @$adata],
 
 	       ##-- relations
-	       relations => [grep {UNIVERSAL::isa(ref($coldb->{$_}),'DiaColloDB::Relation')} keys %$coldb],
+	       #relations => [$coldb->relations],
+	       relations => { map {($_=>$coldb->{$_}->dbinfo($coldb))} $coldb->relations },
 
 	       ##-- overrides
 	       %{$coldb->{info}//{}},
@@ -1154,6 +1155,13 @@ sub relation {
   return $_[0]->{$_[0]->relname($_[1])};
 }
 
+##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+## @relnames = $coldb->relations()
+##  + gets list of defined relations
+sub relations {
+  return grep {UNIVERSAL::isa(ref($_[0]{$_}),'DiaColloDB::Relation')} keys %{$_[0]};
+}
+
 ##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ## \@ids = $coldb->enumIds($enum,$req,%opts)
 ##  + parses enum IDs for $req, which is one of:
@@ -1267,7 +1275,7 @@ sub xidsByDate {
   my ($xi,$d);
   foreach $xi (@$xids) {
     $d = unpack($pack_xd, $xenum->i2s($xi));
-    next if ($dfilter && !$dfilter->($d));
+    next if (($dfilter && !$dfilter->($d)) || $d < $coldb->{xdmin} || $d > $coldb->{xdmax});
     $d = $slice ? int($d/$slice)*$slice : 0;
     push(@{$d2xis->{$d}}, $xi);
   }
@@ -1681,7 +1689,7 @@ sub parseGroupBy {
   my $gbexprs   = [$gbdate];
   my $gbfilters = [];
   my ($gbrestr);
-  if (!ref($req) && $req =~ m{^\s*(?:\#by)?\[([^\]]*)\]}) {
+  if (!ref($req) && $req =~ m{^\s*(?:\#by)?\s*\[(.*)\]\s*$}) {
     ##-- ddc-style request; no restriction-clauses are allowed
     my $cbstr = $1;
     my $gbq = $coldb->qparse("count(*) #by[$cbstr]")
@@ -1733,7 +1741,7 @@ sub parseGroupBy {
 ##     ##
 ##     ##-- scoring and trimming parameters
 ##     eps     => $eps,           ##-- smoothing constant (default=0)
-##     score   => $func,          ##-- scoring function ("f"|"fm"|"mi"|"ld") : default="f"
+##     score   => $func,          ##-- scoring function (f|fm|lf|lfm|mi|ld) : default="f"
 ##     kbest   => $k,             ##-- return only $k best collocates per date (slice) : default=-1:all
 ##     cutoff  => $cutoff,        ##-- minimum score
 ##     global  => $bool,          ##-- trim profiles globally (vs. locally for each date-slice?) (default=0)
@@ -1799,10 +1807,11 @@ sub profile {
 ##     ##
 ##     ##-- scoring and trimming parameters
 ##     eps     => $eps,           ##-- smoothing constant (default=0)
-##     score   => $func,          ##-- scoring function ("f"|"fm"|"mi"|"ld") : default="f"
+##     score   => $func,          ##-- scoring function (f|fm|lf|lfm|mi|ld) : default="f"
 ##     kbest   => $k,             ##-- return only $k best collocates per date (slice) : default=-1:all
 ##     cutoff  => $cutoff,        ##-- minimum score (UNUSED for comparison profiles)
 ##     global  => $bool,          ##-- trim profiles globally (vs. locally for each date-slice?) (default=0)
+##     diff    => $diff,          ##-- low-level score-diff operation (diff|adiff|sum|min|max|avg|havg); default='adiff'
 ##     ##
 ##     ##-- profiling and debugging parameters
 ##     strings => $bool,          ##-- do/don't stringify (default=do)
@@ -1836,6 +1845,7 @@ sub compare {
   $opts{kbest}   //= -1;
   $opts{cutoff}  //= '';
   $opts{global}  //= 0;
+  $opts{diff}    //= 'adiff';
   $opts{strings} //= 1;
 
   ##-- debug
@@ -1847,7 +1857,7 @@ sub compare {
 		      (map {["a$_"=>$opts{"a$_"}]} (qw(query date slice))),
 		      (map {["b$_"=>$opts{"b$_"}]} (qw(query date slice))),
 		      [groupby=>(UNIVERSAL::isa($opts{groupby},'ARRAY') ? join(',',@{$opts{groupby}}) : $opts{groupby})],
-		      (map {[$_=>$opts{$_}]} qw(score eps kbest cutoff global)),
+		      (map {[$_=>$opts{$_}]} qw(score eps kbest cutoff global diff)),
 		     ))
 	       .")");
 
