@@ -7,6 +7,7 @@ package DiaColloDB::Relation;
 use DiaColloDB::Persistent;
 use DiaColloDB::Profile;
 use DiaColloDB::Profile::Multi;
+use DiaColloDB::Utils qw(:si);
 use strict;
 
 ##==============================================================================
@@ -50,6 +51,22 @@ sub union {
   $rel->logconfess("union(): abstract method called");
 }
 
+##==============================================================================
+## Relation API: info
+
+## \%info = $rel->dbinfo($coldb)
+##  + embedded info-hash for $coldb->dbinfo()
+sub dbinfo {
+  my $rel = shift;
+  my $info = { class=>ref($rel) };
+  if ($rel->can('du')) {
+    $info->{du_b} = $rel->du();
+    $info->{du_h} = si_str($info->{du_b});
+  }
+  return $info;
+}
+
+
 ##==============================================================================
 ## Relation API: profiling & comparison: top-level
 
@@ -191,6 +208,7 @@ sub profile {
 ##     kbest   => $k,             ##-- return only $k best collocates per date (slice) : default=-1:all
 ##     cutoff  => $cutoff,        ##-- minimum score
 ##     global  => $bool,          ##-- trim profiles globally (vs. locally for each date-slice?) (default=0)
+##     diff    => $diff,          ##-- low-level score-diff operation (adiff|diff|sum|min|max|avg|havg); default='adiff'
 ##     ##
 ##     ##-- profiling and debugging parameters
 ##     strings => $bool,          ##-- do/don't stringify (default=do)
@@ -220,12 +238,14 @@ sub compare {
   $reldb->vlog($logProfile, "compare(): align and trim (".($opts{global} ? 'global' : 'local').")");
   my $ppairs = DiaColloDB::Profile::MultiDiff->align($mpa,$mpb);
   DiaColloDB::Profile::MultiDiff->trimPairs($ppairs, %opts);
-  my $diff = DiaColloDB::Profile::MultiDiff->new($mpa,$mpb,titles=>$mpa->{titles});
-  $diff->trim(kbesta=>$opts{kbest}) if (!$opts{global});
+  my $diff = DiaColloDB::Profile::MultiDiff->new($mpa,$mpb, titles=>$mpa->{titles}, diff=>$opts{diff});
+  $diff->trim( DiaColloDB::Profile::Diff->diffkbest($opts{diff})=>$opts{kbest} ) if (!$opts{global});
 
   ##-- finalize: stringify
-  $reldb->vlog($logProfile, "compare(): stringify");
-  $diff->stringify($groupby->{g2s}) if ($opts{strings}//1);
+  if ($opts{strings}//1) {
+    $reldb->vlog($logProfile, "compare(): stringify");
+    $diff->stringify($groupby->{g2s});
+  }
 
   return $diff;
 }
