@@ -494,6 +494,19 @@ sub union {
   return $cof;
 }
 
+##==============================================================================
+## Relation API: dbinfo
+
+## \%info = $rel->dbinfo($coldb)
+##  + embedded info-hash for $coldb->dbinfo()
+sub dbinfo {
+  my $cof = shift;
+  my $info = $cof->SUPER::dbinfo();
+  @$info{qw(fmin dmax size1 size2 N)} = @$cof{qw(fmin dmax size1 size2 N)};
+  return $info;
+}
+
+
 ##==============================================================================
 ## Utilities: lookup
 
